summaryrefslogtreecommitdiffstats
path: root/wp-includes/author-template.php
diff options
context:
space:
mode:
Diffstat (limited to 'wp-includes/author-template.php')
-rw-r--r--wp-includes/author-template.php35
1 files changed, 21 insertions, 14 deletions
diff --git a/wp-includes/author-template.php b/wp-includes/author-template.php
index c52a17e..a98bc63 100644
--- a/wp-includes/author-template.php
+++ b/wp-includes/author-template.php
@@ -1,14 +1,15 @@
<?php
-function get_the_author($idmode = '') {
+function get_the_author($deprecated = '') {
global $authordata;
return apply_filters('the_author', $authordata->display_name);
}
-function the_author($idmode = '', $echo = true) {
- if ( $echo )
- echo get_the_author($idmode);
- return get_the_author($idmode);
+// Using echo = false is deprecated. Use get_the_author instead.
+function the_author($deprecated = '', $deprecated_echo = true) {
+ if ( $deprecated_echo )
+ echo get_the_author();
+ return get_the_author();
}
function get_the_author_description() {
@@ -80,6 +81,14 @@ function the_author_url() {
echo get_the_author_url();
}
+function the_author_link() {
+ if (get_the_author_url()) {
+ echo '<a href="' . get_the_author_url() . '" title="' . sprintf(__("Visit %s's website"), get_the_author()) . '" rel="external">' . get_the_author() . '</a>';
+ } else {
+ the_author();
+ }
+}
+
function get_the_author_icq() {
global $authordata;
return $authordata->icq;
@@ -126,20 +135,20 @@ function the_author_posts() {
echo get_the_author_posts();
}
-/* the_author_posts_link() requires no get_, use get_author_link() */
-function the_author_posts_link($idmode='') {
+/* the_author_posts_link() requires no get_, use get_author_posts_url() */
+function the_author_posts_link($deprecated = '') {
global $authordata;
- echo '<a href="' . get_author_link(0, $authordata->ID, $authordata->user_nicename) . '" title="' . sprintf(__("Posts by %s"), wp_specialchars(the_author($idmode, false))) . '">' . the_author($idmode, false) . '</a>';
+ echo '<a href="' . get_author_posts_url($authordata->ID, $authordata->user_nicename) . '" title="' . sprintf(__("Posts by %s"), wp_specialchars(get_the_author())) . '">' . get_the_author() . '</a>';
}
-function get_author_link($echo = false, $author_id, $author_nicename = '') {
+function get_author_posts_url($author_id, $author_nicename = '') {
global $wpdb, $wp_rewrite, $post, $cache_userdata;
$auth_ID = $author_id;
$link = $wp_rewrite->get_author_permastruct();
if ( empty($link) ) {
- $file = get_settings('home') . '/';
+ $file = get_option('home') . '/';
$link = $file . '?author=' . $auth_ID;
} else {
if ( '' == $author_nicename ) {
@@ -148,13 +157,11 @@ function get_author_link($echo = false, $author_id, $author_nicename = '') {
$author_nicename = $user->user_nicename;
}
$link = str_replace('%author%', $author_nicename, $link);
- $link = get_settings('home') . trailingslashit($link);
+ $link = get_option('home') . trailingslashit($link);
}
$link = apply_filters('author_link', $link, $author_id, $author_nicename);
- if ( $echo )
- echo $link;
return $link;
}
@@ -195,7 +202,7 @@ function wp_list_authors($args = '') {
if ( !$hide_empty )
$link = $name;
} else {
- $link = '<a href="' . get_author_link(0, $author->ID, $author->user_nicename) . '" title="' . sprintf(__("Posts by %s"), wp_specialchars($author->display_name)) . '">' . $name . '</a>';
+ $link = '<a href="' . get_author_posts_url($author->ID, $author->user_nicename) . '" title="' . sprintf(__("Posts by %s"), wp_specialchars($author->display_name)) . '">' . $name . '</a>';
if ( (! empty($feed_image)) || (! empty($feed)) ) {
$link .= ' ';